@@ -1,4 +1,4 @@
-/* 
+/*
  * threadSvKeylist.c --
  *
  * This file implements keyed-list commands as part of the thread
@@ -14,6 +14,7 @@
  */
 
 #include "threadSvCmd.h"
+#include "threadSvKeylistCmd.h"
 #include "tclXkeylist.h"
 
 /*
@@ -67,10 +68,10 @@ Sv_RegisterKeylistCommands(void)
     if (initialized == 0) {
         Tcl_MutexLock(&initMutex);
         if (initialized == 0) {
-            Sv_RegisterCommand("keylset",  SvKeylsetObjCmd,  NULL, NULL);
-            Sv_RegisterCommand("keylget",  SvKeylgetObjCmd,  NULL, NULL);
-            Sv_RegisterCommand("keyldel",  SvKeyldelObjCmd,  NULL, NULL);
-            Sv_RegisterCommand("keylkeys", SvKeylkeysObjCmd, NULL, NULL);
+            Sv_RegisterCommand("keylset",  SvKeylsetObjCmd,  NULL, 0);
+            Sv_RegisterCommand("keylget",  SvKeylgetObjCmd,  NULL, 0);
+            Sv_RegisterCommand("keyldel",  SvKeyldelObjCmd,  NULL, 0);
+            Sv_RegisterCommand("keylkeys", SvKeylkeysObjCmd, NULL, 0);
             Sv_RegisterObjType(&keyedListType, DupKeyedListInternalRepShared);
             initialized = 1;
         }
@@ -106,9 +107,9 @@ SvKeylsetObjCmd(arg, interp, objc, objv)
     char *key;
     Tcl_Obj *val;
     Container *svObj = (Container*)arg;
-    
+
     /*
-     * Syntax: 
+     * Syntax:
      *          sv::keylset array lkey key value ?key value ...?
      *          $keylist keylset key value ?key value ...?
      */
@@ -120,7 +121,7 @@ SvKeylsetObjCmd(arg, interp, objc, objv)
     }
     if ((objc - off) < 2 || ((objc - off) % 2)) {
         Tcl_WrongNumArgs(interp, off, objv, "key value ?key value ...?");
-        goto cmd_err;   
+        goto cmd_err;
     }
     for (i = off; i < objc; i += 2) {
         key = Tcl_GetString(objv[i]);
@@ -128,7 +129,7 @@ SvKeylsetObjCmd(arg, interp, objc, objv)
         ret = TclX_KeyedListSet(interp, svObj->tclObj, key, val);
         if (ret != TCL_OK) {
             goto cmd_err;
-        } 
+        }
     }
 
     return Sv_PutContainer(interp, svObj, SV_CHANGED);
@@ -167,7 +168,7 @@ SvKeylgetObjCmd(arg, interp, objc, objv)
     Container *svObj = (Container*)arg;
 
     /*
-     * Syntax: 
+     * Syntax:
      *          sv::keylget array lkey ?key? ?var?
      *          $keylist keylget ?key? ?var?
      */
@@ -179,7 +180,7 @@ SvKeylgetObjCmd(arg, interp, objc, objv)
     }
     if ((objc - off) > 2) {
         Tcl_WrongNumArgs(interp, off, objv, "?key? ?var?");
-        goto cmd_err;   
+        goto cmd_err;
     }
     if ((objc - off) == 0) {
         if (Sv_PutContainer(interp, svObj, SV_UNCHANGED) != TCL_OK) {
@@ -192,7 +193,7 @@ SvKeylgetObjCmd(arg, interp, objc, objv)
     } else {
         varObjPtr = NULL;
     }
-    
+
     key = Tcl_GetString(objv[off]);
     ret = TclX_KeyedListGet(interp, svObj->tclObj, key, &valObjPtr);
     if (ret == TCL_ERROR) {
@@ -201,8 +202,7 @@ SvKeylgetObjCmd(arg, interp, objc, objv)
 
     if (ret == TCL_BREAK) {
         if (varObjPtr) {
-            Tcl_ResetResult(interp);
-            Tcl_SetBooleanObj(Tcl_GetObjResult(interp), 0);
+            Tcl_SetObjResult(interp, Tcl_NewIntObj(0));
         } else {
             Tcl_AppendResult (interp, "key \"", key, "\" not found", NULL);
             goto cmd_err;
@@ -210,11 +210,9 @@ SvKeylgetObjCmd(arg, interp, objc, objv)
     } else {
         Tcl_Obj *resObjPtr = Sv_DuplicateObj(valObjPtr);
         if (varObjPtr) {
-            int len;
-            Tcl_ResetResult(interp);
-            Tcl_SetBooleanObj(Tcl_GetObjResult(interp), 1);
-            Tcl_GetStringFromObj(varObjPtr, &len);
-            if (len) {
+            Tcl_SetObjResult(interp, Tcl_NewIntObj(1));
+            Tcl_GetString(varObjPtr);
+            if (varObjPtr->length) {
                 Tcl_ObjSetVar2(interp, varObjPtr, NULL, resObjPtr, 0);
             }
         } else {
@@ -257,7 +255,7 @@ SvKeyldelObjCmd(arg, interp, objc, objv)
     Container *svObj = (Container*)arg;
 
     /*
-     * Syntax: 
+     * Syntax:
      *          sv::keyldel array lkey key ?key ...?
      *          $keylist keyldel ?key ...?
      */
@@ -280,7 +278,7 @@ SvKeyldelObjCmd(arg, interp, objc, objv)
             goto cmd_err;
         }
     }
-    
+
     return Sv_PutContainer(interp, svObj, SV_CHANGED);
 
  cmd_err:
@@ -317,7 +315,7 @@ SvKeylkeysObjCmd(arg, interp, objc, objv)
     Container *svObj = (Container*)arg;
 
     /*
-     * Syntax: 
+     * Syntax:
      *          sv::keylkeys array lkey ?key?
      *          $keylist keylkeys ?key?
      */
@@ -344,7 +342,7 @@ SvKeylkeysObjCmd(arg, interp, objc, objv)
     }
 
     Tcl_SetObjResult (interp, listObj); /* listObj allocated by API !*/
-    
+
     return Sv_PutContainer(interp, svObj, SV_UNCHANGED);
 
  cmd_err:
